import { NextFunction, Request, Response } from 'express';
import { AuthService } from '@/services/auth.service';
import { IRequestWithUser } from '@/interfaces/IRequestWithUser';
import { IUser } from '@/interfaces/IUser.interface';

const service = new AuthService();
export const authValidate = async (req: Request, res: Response, next: NextFunction) => {
  const token = req.header('Authorization');

  if (!token) {
    return res.status(401).send({ error: { message: 'Token not passed' } });
  }

  const user = await service.getUserByToken(token);

  if (!user) {
    return res.status(401).send({ error: { message: 'Invalid token' } });
  }

  (req as IRequestWithUser).user = user as unknown as IUser;
  next();
  return;
};
